#!/usr/bin/perl
##############################################################################
# Copyright (c) 2005
# Author Sylvain Daubert <gwine@free.fr>
#
# This program is free software; you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published by the Free 
# Software Foundation; either version 2 of the License, or (at your option) 
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 675 Mass 
# Ave, Cambridge, MA 02139, USA.
# Sylvain Daubert <gwine@free.fr>
#############################################################################
require 5.8.1;
use strict;
use warnings;

package DialogCellar;

BEGIN {
    use Encode;
    use Gtk2::GladeXML;
    use Locale::TextDomain qw( gwine );
}

use constant FALSE => 0;
use constant TRUE  => 1;


##################################################################
## helper function
##################################################################
sub __u { decode('UTF-8', __($_[0])) }
sub __xu { decode('UTF-8', __x(@_)) }


#############################################################
## Callbacks
#############################################################

sub on_response_event { shift->destroy }


#############################################################
## Methods
#############################################################

sub new {    
    my $that = shift;
    my $class = ref($that) || $that;
    my $self = {};
    bless $self, $class;
}


sub create {
    # Create new dialog
    my $self = new(shift);
    my $path = shift;
    my $class = ref $self;

    my $xml = Gtk2::GladeXML->new("$path/gwine.glade", 'dialog_cellar', 
				  'gwine');
    $self->{xml} = $xml;
    $xml->signal_autoconnect_from_package('DialogCellar');

    ## Set List (tview)
    my @cols;
    @cols =(__u('Date'), __u('Number'), __u('Appellation'), __u('Domain'), 
	    __u('Vintage'), __u('Price'), __u('Comments'));
    my $store = Gtk2::ListStore->new('Glib::String', 'Glib::String',
				     'Glib::String', 'Glib::String',
				     'Glib::String', 'Glib::String', 
				     'Glib::String');
    $xml->get_widget('tview')->set_model($store);
    $xml->get_widget('tview')->set_headers_clickable(FALSE);
    for (my $i = 0; $i < 7; $i++) {
	my $renderer = Gtk2::CellRendererText->new;
	my $col = Gtk2::TreeViewColumn->new_with_attributes($cols[$i], 
							    $renderer,
							    'text', $i);
	$col->set_clickable(FALSE);
	$col->set_resizable(TRUE);
	$xml->get_widget('tview')->append_column($col);
    }

    my $select = $xml->get_widget('tview')->get_selection;
    $select->set_mode('single');

    ## sort list by date
    my $lh = Gwine::L10N->get_l10n();
    my $sort_func = sub {
	my $a = $_[0]->get_value($_[1], 0);
	my $b = $_[0]->get_value($_[2], 0);
	return $lh->sort_by_date($a, $b)
    };
    $store->set_default_sort_func($sort_func);
    $store->set_sort_column_id(0, 'ascending');
    $store->set_sort_func(0, $sort_func);

    return $self
}


# Add entry in list
sub add_entry {
    my $self = shift;
    my ($n, $date, $app, $domain, $age, $price, $comments) = @_;

    my $lh = Gwine::L10N->get_l10n();

    $price = ($price eq '') ? '' : $lh->numf($price);

    my $store = $self->xml->get_widget('tview')->get_model;
    my $ins_iter = $store->append;
    $store->set($ins_iter,
		0 => $date,
		1 => $n,
		2 => $app,
		3 => $domain,
		4 => $age,
		5 => $price, 
		6 => $comments);
}


sub xml { return $_[0]->{xml} }
sub top { return $_[0]->{xml}->get_widget('dialog_pref') }


1;

__END__
