#!/usr/bin/perl
##############################################################################
# Copyright (c) 2005
# Author Sylvain Daubert <gwine@free.fr>
#
# This program is free software; you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published by the Free 
# Software Foundation; either version 2 of the License, or (at your option) 
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 675 Mass 
# Ave, Cambridge, MA 02139, USA.
# Sylvain Daubert <gwine@free.fr>
#############################################################################
require 5.8.1;
use strict;
use warnings;

package DialogProd;

BEGIN {
    use Encode;
    use Gtk2::GladeXML;
    use Locale::TextDomain qw( gwine );
}

use constant FALSE => 0;
use constant TRUE  => 1;


##################################################################
## helper function
##################################################################
sub __u { decode('UTF-8', __($_[0])) }
sub __xu { decode('UTF-8', __x(@_)) }


#############################################################
## Internal function
#############################################################

sub create_prod_from_dialog {
    my $xml = shift;

    my $name = $xml->get_widget('entry_name')->get_text;
    my $address = $xml->get_widget('entry_addr')->get_text;
    my $zip = $xml->get_widget('entry_zip')->get_text;
    my $city = $xml->get_widget('entry_city')->get_text;
    my $country = $xml->get_widget('entry_country')->get_text;
    my $phone = $xml->get_widget('entry_phone')->get_text;
    
    # Create new producer
    return Gwine::GProd->new($name, $address, $zip, 
			     $city, $country, $phone);
}


#############################################################
## Callbacks
#############################################################

sub on_response_event {
    my $dialog = shift;
    my $rep = shift;
    my $p = shift;
    my ($xml, $db, $prod_id) = @$p;

    if (($rep eq 'cancel') or ($rep eq 'delete-event')) {
	$dialog->destroy;
	return
    }
    
    # rep is 'ok' or 'apply'
    my $prod = create_prod_from_dialog($xml);
    if (defined $prod) {
	if (defined $prod_id) {
	    # Modifying an existing producer
	    # Add it to database
	    $db->prod->by_id($prod_id, $prod);
	    # Refresh list
	    AppGwine::list_prods();
	}
	else { # Creating a new producer
	    # Add it to database
	    $prod_id = $db->prod->add($prod);
	    # Add producer to prod list
	    AppGwine::add_prod($prod, $db);
	    if ($rep eq 'apply') {
		# If 'apply', then reconnect callback with prod_id 
		# because dialog becomes a modify dialog
		$dialog->signal_handlers_disconnect_by_func('DialogProd::on_response_event');
		$dialog->signal_connect('response', 
					"DialogProd::on_response_event", 
					[$xml, $db, $prod_id]);
	    }
	}
    }

    $dialog->destroy if $rep eq 'ok'
}


#############################################################
## Methods
#############################################################

sub new {    
    my $that = shift;
    my $class = ref($that) || $that;
    my $self = {};
    bless $self, $class;
}


sub create {
    # Create new dialog
    my $self = new(shift);
    my $path = shift;
    my $db = shift;
    my $prod_id = shift;
    my $class = ref $self;

    my $xml = Gtk2::GladeXML->new("$path/gwine.glade", 'dialog_prod',
				  'gwine');
    $self->{xml} = $xml;
    $xml->signal_autoconnect_from_package('DialogProd');
    $xml->get_widget('dialog_prod')->signal_connect('response', 
						    "$class\::on_response_event", 
						    [$xml, $db, $prod_id]);
    return $self
}


sub xml { return $_[0]->{xml} }
sub top { return $_[0]->{xml}->get_widget('dialog_prod') }


1;

__END__
