#!/usr/bin/perl
##############################################################################
# Copyright (c) 2003
# Author Sylvain Daubert <gwine@free.fr>
#
# This program is free software; you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published by the Free 
# Software Foundation; either version 2 of the License, or (at your option) 
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 675 Mass 
# Ave, Cambridge, MA 02139, USA.
# Sylvain Daubert <gwine@free.fr>
#############################################################################
## Define GAppel class
#############################################################################
## This class defines an appellation versus a vineyard
#############################################################################


package Gwine::GAppel;
use strict;
use warnings;

#############################################################################
## Creator
## Parameters :
##    appel   : string : name of appellation
##    vine    : int    : number of appellation's vineyard
#############################################################################
sub new {

    my $proto = shift;

    my $class = ref($proto) || $proto;
    my $self = {};

    bless($self,$class);

    $self->{appel} = shift;
    $self->{vine} = shift;
    $self->{extensions} = [];

    return $self;
}


#############################################################################
## Method to add an extension
## Return position of extension in list
#############################################################################
sub add_extension {
    my $self = shift;
    my $extension = shift;

    my $list = $self->{extensions};
    for( my $i = 0 ; $i < @{$list} ; $i++) {
	if ($list->[$i] eq "null") { 
	    $list->[$i] = $extension;
	    return $i;
	}
    }
    push @{$list}, $extension;
    return scalar @{$list} - 1;
}

#############################################################################
## Method to delete an extension
## Return new size of list, -1 if not deleted
#############################################################################
sub delete_extension {
    my $self = shift;
    my $extension = shift;
    my $list = $self->{extensions};

    if ($extension >= @$list) { return -1 }

    if ($extension == @$list-1) { pop @$list }
    else { $list->[$extension] = 'null' }
	
    return scalar @$list;
}

#############################################################################
## Method to get an extension
## Return extension from its id, "-1" if not found
#############################################################################
sub get_extension {
    my $self = shift;
    my $id = shift;;

    if ($id < @{$self->{extensions}}) { return $self->{extensions}->[$id] }
    else { return "-1" }
}

#############################################################################
## Method to set an extension id with extension
## Return extension
#############################################################################
sub set_extension_id {
    my $self = shift;
    my $id = shift;
    my $extension = shift;
    return $self->{extensions}->[$id] = $extension;
}

#############################################################################
## Method to get an extension id
## Return extension id from its name, -1 if not found
#############################################################################
sub get_extension_id {
    my $self = shift;
    my $name = shift;;

    my $list = $self->{extensions};
    for( my $i = 0 ; $i < @$list ; $i++) {
	if ($$list[$i] eq $name) { return $i }
    }
    return -1;
}


#############################################################################
## Methods to access per-object data
## With args, they set the value, else they only retrieve it.
#############################################################################
sub appellation {
    my $self = shift;
    if (@_) {$self->{appel} = shift}
    return $self->{appel};
}

sub vineyard {
    my $self = shift;
    if (@_) {$self->{vine} = shift}
    return $self->{vine};
}

sub extensions {
    my $self = shift;
    if (@_) {$self->{extensions} = shift}
    return $self->{extensions};
}



1;

__END__
