#!/usr/bin/perl -w
##############################################################################
# Copyright (c) 2003
# Author Sylvain Daubert <gwine@free.fr>
#
# This program is free software; you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published by the Free 
# Software Foundation; either version 2 of the License, or (at your option) 
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 675 Mass 
# Ave, Cambridge, MA 02139, USA.
# Sylvain Daubert <gwine@free.fr>
#############################################################################
## Define GList class
#############################################################################
## This class defines a list of all that you want
#############################################################################


package Gwine::GList;
require 5.006;
use strict;


#############################################################################
## Creator
## Parameters :
##    none
#############################################################################
sub new {
    my $proto = shift;

    my $class = ref($proto) || $proto;
    my $self = [];

    bless($self,$class);

    return $self;
}


#############################################################################
## Method to access list of ref
## Return a list (some elements may be set to -1).
#############################################################################
sub list {
  my $self = shift;
  my @list = @$self;

  return @list;
}


#############################################################################
## Method to get list size
## Return an integer
#############################################################################
sub size {
  my $self = shift;
  my $size = @$self;
  return $size;
}


#############################################################################
## Method to get list size. Only real items are counted
## Return an integer
#############################################################################
sub true_size {
  my $self = shift;
  my $size = @$self;
  foreach (@$self) {
      $size-- if !defined $_;
      $size-- if $_ eq '-1';
  }
  return $size;
}


#############################################################################
## Method to access object by number
## With ref arg, set the value, else only retrieve it
#############################################################################
sub by_id {
  my $self = shift;
  my $nb = shift;

  if (@_) {$self->[$nb] = shift}
  elsif ($nb >= @$self or $nb < 0) {return -1}
  return $self->[$nb];
}


#############################################################################
## Method to give number in list from ref
## Return an integer
#############################################################################
sub get_id {
  my $self = shift;
  my $ref = shift;

  for( my $i = 0; $i < @$self; $i++ ) {
      my $test = $self->[$i];
      if ($self->[$i] eq $ref) { return $i }
  }
  return -1;
}


#############################################################################
## Method to add an object in list
## Param : ref on an object
## Return id of new item
#############################################################################
sub add {
    my $self = shift;

    my $ref = shift;
    # Already exist ?
    foreach (@$self) { if ($_ eq $ref) {return} }
    # searching for an empty item
    my $i = 0;
    foreach (@$self) {
	if ($_ eq -1) {
	    $self->[$i] = $ref;
	    return $i;
	}
	$i++;
    }
    push (@$self, $ref);
    return $i;
}


#############################################################################
## Method to delete an object from list
## Param : ref on an object to delete from list
#############################################################################
sub del {
    my $self = shift;

    my $ref = shift;
    my $i = 0;
    foreach (@$self) {
	if ($_ eq $ref ) {
	    $self->[$i] = -1;
	    return;
	}
	$i++;
    }
}


#############################################################################
## Method to delete an object from list
## Param : Object's Id in list
#############################################################################
sub del_by_id {
    my $self = shift;

    my $id = shift;
    $self->[$id] = -1;
}





1;

__END__
