#!/usr/bin/perl
##############################################################################
# Copyright (c) 2003
# Author Sylvain Daubert <gwine@free.fr>
#
# This program is free software; you can redistribute it and/or modify it 
# under the terms of the GNU General Public License as published by the Free 
# Software Foundation; either version 2 of the License, or (at your option) 
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 675 Mass 
# Ave, Cambridge, MA 02139, USA.
# Sylvain Daubert <gwine@free.fr>
#############################################################################
## Define GZone class
#############################################################################
## This class defines a geographical zone. This may correspond to an 
## old vineyard (db format 1) but it's more flexible. GZones may be 
## created hierarchically (exemple : Defines GZones France->Bordeaux->
## Haut Mdoc, and in Haut Mdoc GZone, you can create an appellation 
## St Julien).
## This class is defined from db format 2.
#############################################################################

package Gwine::GZone;
use warnings;
use strict;

#############################################################################
## Creator
## Parameters :
##    zone   : string : name of zone
##    parent : int    : id of parent (-1 if none)
#############################################################################
sub new {

    my $proto = shift;

    my $class = ref($proto) || $proto;
    my $self = {};

    bless($self,$class);

    $self->{zone} = shift;
    $self->{parent} = shift;

    return $self;
}


#############################################################################
## Methods to access per-object data
## With args, they set the value, else they only retrieve it.
#############################################################################
sub zone {
    my $self = shift;
    if (@_) { $self->{zone} = shift }
    return $self->{zone};
}

sub parent {
    my $self = shift;
    if (@_) { $self->{parent} = shift }
    return $self->{parent};
}



1;

__END__
